==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/data/danmaku/DanmakuTrajectory.java <==
package cc.thonly.reverie_dreams.data.danmaku;

import cc.thonly.reverie_dreams.component.DanmakuProperties;
import cc.thonly.reverie_dreams.registry.content.component.RDDataComponentTypes;
import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.registry.impl.RegistryHandler;
import cc.thonly.reverie_dreams.registry.interfaces.BuiltinObject;
import cc.thonly.reverie_dreams.registry.interfaces.CodecStep;
import cc.thonly.reverie_dreams.registry.interfaces.OwnerBinding;
import com.mojang.serialization.Codec;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_3218;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

@Setter
@Getter
@NoArgsConstructor
public class DanmakuTrajectory implements CodecStep<DanmakuTrajectory>, OwnerBinding<DanmakuTrajectory>, BuiltinObject {
    public static final Codec<DanmakuTrajectory> CODEC = Codec.unit(DanmakuTrajectory::new);
    private RegistryHandler<DanmakuTrajectory> owner;

    public void run(class_3218 world, @Nullable class_1309 livingEntity, class_1799 stack, Double x, Double y, Double z, float pitch, float yaw, float divergence, float offsetDist, IDanmakuItem pThis) {

    }

    public static DanmakuEntity spawnByItemStack(class_3218 world, @NotNull class_1309 livingEntity, class_1799 stack, Float divergence, Float offsetDist) {
        stack = stack.method_7972();
        double x = livingEntity.method_23317();
        double y = livingEntity.method_23318();
        double z = livingEntity.method_23321();
        if (offsetDist == null) {
            offsetDist = 1.5f;
        }
        DanmakuProperties properties = stack.method_58695(RDDataComponentTypes.DANMAKU_PROPERTIES, DanmakuProperties.ofDefault());
        DanmakuEntity danmakuEntity = new DanmakuEntity(
                livingEntity,
                world,
                x, y, z,
                stack,
                properties,
                livingEntity.method_36455(), livingEntity.method_36454(),
                divergence, offsetDist
        );
        world.method_8649(danmakuEntity);
        return danmakuEntity;
    }

    public static DanmakuEntity spawnByItemStack(class_3218 world, @Nullable class_1309 livingEntity, Double x, Double y, Double z, class_1799 stack, Float pitch, Float yaw, Float divergence, Float offsetDist) {
        stack = stack.method_7972();
        if (offsetDist == null) {
            offsetDist = 1.5f;
        }
        DanmakuProperties properties = stack.method_58695(RDDataComponentTypes.DANMAKU_PROPERTIES, DanmakuProperties.ofDefault());
        DanmakuEntity danmakuEntity = new DanmakuEntity(
                livingEntity,
                world,
                x, y, z,
                stack,
                properties,
                pitch, yaw,
                divergence, offsetDist
        );
        world.method_8649(danmakuEntity);
        return danmakuEntity;
    }

    @Override
    public Codec<DanmakuTrajectory> getCodec() {
        return CODEC;
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/data/danmaku/DanmakuTrajectory.java <==
package cc.thonly.reverie_dreams.data.danmaku;

import cc.thonly.reverie_dreams.component.DanmakuProperties;
import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.registry.content.component.RDDataComponents;
import cc.thonly.reverie_dreams.registry.impl.RegistryHandler;
import cc.thonly.reverie_dreams.registry.interfaces.BuiltinObject;
import cc.thonly.reverie_dreams.registry.interfaces.CodecStep;
import cc.thonly.reverie_dreams.registry.interfaces.OwnerBinding;
import com.mojang.serialization.Codec;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_3218;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

@Setter
@Getter
@NoArgsConstructor
public class DanmakuTrajectory implements CodecStep<DanmakuTrajectory>, OwnerBinding<DanmakuTrajectory>, BuiltinObject {
    public static final Codec<DanmakuTrajectory> CODEC = Codec.unit(DanmakuTrajectory::new);
    private RegistryHandler<DanmakuTrajectory> owner;

    public void run(class_3218 world, @Nullable class_1309 livingEntity, class_1799 stack, Double x, Double y, Double z, float pitch, float yaw, float divergence, float offsetDist, IDanmakuItem pThis) {

    }

    public static DanmakuEntity spawnByItemStack(class_3218 world, @NotNull class_1309 livingEntity, class_1799 stack, Float divergence, Float offsetDist) {
        stack = stack.method_7972();
        double x = livingEntity.method_23317();
        double y = livingEntity.method_23318();
        double z = livingEntity.method_23321();
        if (offsetDist == null) {
            offsetDist = 1.5f;
        }
        DanmakuProperties properties = stack.method_58695(RDDataComponents.DANMAKU_PROPERTIES, DanmakuProperties.ofDefault());
        DanmakuEntity danmakuEntity = new DanmakuEntity(
                livingEntity,
                world,
                x, y, z,
                stack,
                properties,
                livingEntity.method_36455(), livingEntity.method_36454(),
                divergence, offsetDist
        );
        world.method_8649(danmakuEntity);
        return danmakuEntity;
    }

    public static DanmakuEntity spawnByItemStack(class_3218 world, @Nullable class_1309 livingEntity, Double x, Double y, Double z, class_1799 stack, Float pitch, Float yaw, Float divergence, Float offsetDist) {
        stack = stack.method_7972();
        if (offsetDist == null) {
            offsetDist = 1.5f;
        }
        DanmakuProperties properties = stack.method_58695(RDDataComponents.DANMAKU_PROPERTIES, DanmakuProperties.ofDefault());
        DanmakuEntity danmakuEntity = new DanmakuEntity(
                livingEntity,
                world,
                x, y, z,
                stack,
                properties,
                pitch, yaw,
                divergence, offsetDist
        );
        world.method_8649(danmakuEntity);
        return danmakuEntity;
    }

    @Override
    public Codec<DanmakuTrajectory> getCodec() {
        return CODEC;
    }
}
